current_app_detector library

Classes

CurrentAppDetector
A class to interact with native platform functionality for detecting the current foreground application and interacting with system features.
CurrentAppDetectorPlugin