checkAccessibilityPermission static method
Checks if the Accessibility Service for this app is enabled.
Returns true if the service is enabled, false otherwise.
Implementation
static Future<bool> checkAccessibilityPermission() async {
try {
final result =
await _channel.invokeMethod<bool>('checkAccessibilityPermission');
return result ?? false;
} on PlatformException catch (e) {
throw Exception(
'Failed to check accessibility permission: ${e.message}');
}
}