menu
current_app_detector package
documentation
current_app_detector.dart
current_app_detector.dart
dark_mode
light_mode
current_app_detector
library
Classes
CurrentAppDetector
A class to interact with native platform functionality for detecting the current foreground application and interacting with system features.
CurrentAppDetectorPlugin
current_app_detector package
documentation
current_app_detector.dart
current_app_detector
package
Libraries
current_app_detector
current_app_detector library